class Template:

  template_model = dict(

    Birthdate = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = "http://purl.obolibrary.org/obo/NCIT_C68615",
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:date",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    Birthyear = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = "http://purl.obolibrary.org/obo/NCIT_C83164",
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:integer",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
    Deathdate = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = "http://purl.obolibrary.org/obo/NCIT_C70810",
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:date",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
    First_visit = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = "http://purl.obolibrary.org/obo/NCIT_C164021",
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:date",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
    Symptoms_onset = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = "http://purl.obolibrary.org/obo/NCIT_C124353",
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:date",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    Sex = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C160908", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
        
    Status = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C164628", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    Education = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = "http://purl.obolibrary.org/obo/NCIT_C17953",
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = "http://purl.obolibrary.org/obo/NCIT_C73537",        
        protocol_id = "https://www.wikidata.org/wiki/Q1390351", 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:integer",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
        
        
    Diagnosis = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C18020",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C154625", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
        
    Phenotype = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C18020",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C16977", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
        
    Genotype = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C15709",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = None, 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
        
    # Zygosity = dict(
    #     pid = None,
    #     process_type = "http://purl.obolibrary.org/obo/NCIT_C15709",
    #     attribute_type = "http://purl.obolibrary.org/obo/NCIT_C181350",
    #     agent_type = None,
    #     agent_id = None,
    #     input_type = None,
    #     #input_id = None,
    #     target_type = "http://purl.obolibrary.org/obo/NCIT_C45766",
    #     target_id = None,     
    #     output_type = None, 
    #     output_id = None,
    #     unit_type = None,
    #     specific_process_type = None,
    #     protocol_type = None,        
    #     protocol_id = None, 
    #     substance_type = None,      
    #     substance_id = None,
    #     activity_type = None,
    #     frequency_type = None,
    #     frequency_value = None,        
    #     concentration_type = None,
    #     concentration_value = None,
    #     concentration_unit_type = None,
    #     value_date = None,
    #     value_integer = None,
    #     value_string = None,
    #     value_float = None,
    #     value_datatype = "xsd:string",
    #     comments = None,
    #     startdate = None,
    #     enddate = None,
    #     age = None,
    #     uniqid = None,
    #     event_id = None,
    #     value = None,
    #     valueIRI = None,
    #     activity = None,
    #     target = None,
    #     agent = None,
    #     input = None,
    #     unit = None
    #     ),
        
        
    # Protein = dict(
    #     pid = None,
    #     process_type = "http://purl.obolibrary.org/obo/NCIT_C18962",
    #     attribute_type = None,
    #     agent_type = None,
    #     agent_id = None,
    #     input_type = None,
    #     #input_id = None,
    #     target_type = "http://purl.obolibrary.org/obo/NCIT_C165059",
    #     target_id = None,     
    #     output_type = None, 
    #     output_id = None,
    #     unit_type = None,
    #     specific_process_type = None,
    #     protocol_type = None,        
    #     protocol_id = None, 
    #     substance_type = None,      
    #     substance_id = None,
    #     activity_type = None,
    #     frequency_type = None,
    #     frequency_value = None,        
    #     concentration_type = None,
    #     concentration_value = None,
    #     concentration_unit_type = None,
    #     value_date = None,
    #     value_integer = None,
    #     value_string = None,
    #     value_float = None,
    #     value_datatype = "xsd:string",
    #     comments = None,
    #     startdate = None,
    #     enddate = None,
    #     age = None,
    #     uniqid = None,
    #     event_id = None,
    #     value = None,
    #     valueIRI = None,
    #     activity = None,
    #     target = None,
    #     agent = None,
    #     input = None,
    #     unit = None
    #     ),
        
        
    Consent_contacted = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/OBI_0000810",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/OBIB_0000488", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
        
    Consent_used = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/OBI_0000810",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/DUO_0000001", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
        
        
    Biobank = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/OMIABIS_0000061",
        attribute_type = None,
        agent_type = "http://purl.obolibrary.org/obo/OBIB_0000616",
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C115570", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    # Exemplar = dict(
    #     pid = None,
    #     process_type = None,
    #     attribute_type = None,
    #     agent_type = None,
    #     agent_id = None,
    #     input_type = None,
    #     #input_id = None,
    #     target_type = None,
    #     target_id = None,     
    #     output_type = None, 
    #     output_id = None,
    #     unit_type = None,
    #     specific_process_type = None,
    #     protocol_type = None,        
    #     protocol_id = None, 
    #     substance_type = None,      
    #     substance_id = None,
    #     activity_type = None,
    #     frequency_type = None,
    #     frequency_value = None,        
    #     concentration_type = None,
    #     concentration_value = None,
    #     concentration_unit_type = None,
    #     value_date = None,
    #     value_integer = None,
    #     value_string = None,
    #     value_float = None,
    #     value_datatype = "xsd:string",
    #     comments = None,
    #     startdate = None,
    #     enddate = None,
    #     age = None,
    #     uniqid = None,
    #     event_id = None,
    #     value = None,
    #     valueIRI = None,
    #     activity = None,
    #     target = None,
    #     agent = None,
    #     input = None,
    #     unit = None
    #     ),
    

    Disability = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C91102",
        attribute_type = "http://purl.obolibrary.org/obo/NCIT_C21007",
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:float",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    Body_measurement = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C142470",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:float",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    Lab_measurement = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C25294",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C70856", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:float",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    Imaging = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C17369",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C81289", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    Surgery = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C15329",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = None, 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = "http://purl.obolibrary.org/obo/NCIT_C73537",        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None
    ),
    
    Medication = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C70962",
        attribute_type = None,
        agent_type = None,
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = None, 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = "http://purl.obolibrary.org/obo/NCIT_C73537",        
        protocol_id = None, 
        substance_type = "http://purl.obolibrary.org/obo/NCIT_C177929",      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = "http://purl.obolibrary.org/obo/NCIT_C25488",
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:float",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None,
        input = None,
        unit = None
        ),
    
    
    Clinical_trial = dict(
        pid = None,
        process_type = "http://purl.obolibrary.org/obo/NCIT_C71104",
        attribute_type = None,
        agent_type = "http://purl.obolibrary.org/obo/NCIT_C16696",
        agent_id = None,
        input_type = None,
        #input_id = None,
        target_type = None,
        target_id = None,     
        output_type = "http://purl.obolibrary.org/obo/NCIT_C115575", 
        output_id = None,
        unit_type = None,
        specific_process_type = None,
        protocol_type = None,        
        protocol_id = None, 
        substance_type = None,      
        substance_id = None,
        activity_type = None,
        frequency_type = None,
        frequency_value = None,        
        concentration_type = None,
        concentration_value = None,
        concentration_unit_type = None,
        value_date = None,
        value_integer = None,
        value_string = None,
        value_float = None,
        value_datatype = "xsd:string",
        comments = None,
        startdate = None,
        enddate = None,
        age = None,
        uniqid = None,
        event_id = None,
        value = None,
        valueIRI = None,
        activity = None,
        target = None,
        agent = None    )

  )