from setuptools import setup

setup(
    name="CARE-SM-Toolkit",
    version="0.0.18",
    packages=["toolkit"],
    author="Pablo Alarcón Moreno",
    author_email="pabloalarconmoreno@gmail.com",
    url="https://github.com/CARE-SM/CARE-SM-Toolkit",
    description="CARE-SM Toolkit",
    license="MIT",
    keywords=["EJP-RD","EJP","FAIR-in-a-box","Fiab","CARE-SM"]
)